@@ -2,7 +2,7 @@ import argparse
 
 import apache_beam as beam
 from apache_beam.io import ReadFromText
-from apache_beam.io import WriteToAvro, WriteToText
+from apache_beam.io import WriteToAvro
 from apache_beam.options.pipeline_options import PipelineOptions, SetupOptions
 
 from pathlib import Path
@@ -70,7 +70,7 @@ def run(argv=None, save_main_session=True):
             output_path = (Path(known_args.output) / schema["name"].replace(".", "_")).as_posix()
             (jsons
              | 'Map' >> beam.Map(lambda data: data["sdata"])
-             | 'WriteToGCS' >> WriteToText(output_path))#WriteToAvro(output_path, schema=schema, file_name_suffix=".avro"))
+             | 'WriteToGCS' >> WriteToAvro(output_path, schema=schema, file_name_suffix=".avro"))
 
 if __name__ == '__main__':
     logging.getLogger().setLevel(logging.INFO)
